==> 1.0.0.tar.gz: lib/src/firework_sdk.dart <==
import 'constants/fw_error_name.dart';
import 'constants/fw_event_name.dart';
import 'fw_event_bus.dart';
import 'live_stream.dart';
import 'models/ad_badge_configuration.dart';
import 'models/ad_config.dart';
import 'models/fw_error.dart';
import 'models/fw_events.dart';
import 'models/fw_method_name.dart';
import 'models/video_player_configuration.dart';
import 'utils/fw_method_channel_util.dart';
import 'utils/model_utils/ad_badge_configuration_util.dart';
import 'utils/model_utils/ad_config_util.dart';
import 'utils/model_utils/fw_events_util.dart';
import 'utils/model_utils/fw_method_name_util.dart';
import 'utils/model_utils/video_player_configuration_util.dart';
import 'video_shopping.dart';

typedef CustomCTAClickCallback = void Function(CustomCTAClickEvent? event);
typedef SDKInitCallback = void Function(SDKInitEvent event);
typedef VideoFeedClickCallback = void Function(VideoFeedClickEvent? event);
typedef VideoPlaybackCallback = void Function(VideoPlaybackEvent? event);

/// The entry class of Firework Flutter SDK, which supports the sdk initialization, global configuration, etc.
class FireworkSDK {
  static FireworkSDK? _instance;

  /// The callback of SDK initialization.
  SDKInitCallback? onSDKInit;

  CustomCTAClickCallback? _onCustomCTAClick;
  VideoPlaybackCallback? _onVideoPlayback;

  /// The callback of clicking video feed.
  VideoFeedClickCallback? onVideoFeedClick;

  String? _shareBaseURL;
  AdBadgeConfiguration? _adBadgeConfiguration;

  /// Get global single instance of FireworkSDK class.
  factory FireworkSDK.getInstance() => _getInstance();

  FireworkSDK._() {
    FWMethodChannelUtil.getFirewokSDKChannel()
        .setMethodCallHandler((call) async {
      final fwMethod = FWMethodNameUtil.createMethodName(call.method);
      if (fwMethod == null) {
        return null;
      }

      switch (fwMethod) {
        case FWMethodName.sdkInit:
          final sdkInitEvent = SDKInitEventUtil.fromJson(call.arguments);
          if (sdkInitEvent != null) {
            onSDKInit?.call(
              sdkInitEvent,
            );
          } else {
            onSDKInit?.call(
              SDKInitEvent(
                error: FWError(
                  name: FWErrorName.parseJsonError,
                  reason: "Fail to parse SDK init event",
                ),
              ),
            );
          }
          break;
        case FWMethodName.customCTAClick:
          onCustomCTAClick?.call(
            CustomCTAClickEventUtil.fromJson(
              call.arguments,
            ),
          );
          break;
        case FWMethodName.videoPlayback:
          onVideoPlayback?.call(
            VideoPlaybackEventUtil.fromJson(
              call.arguments,
            ),
          );
          break;
        case FWMethodName.videoFeedClick:
          onVideoFeedClick?.call(
            VideoFeedClickEventUtil.fromJson(
              call.arguments,
            ),
          );
          break;
      }

      return null;
    });
  }

  /// The configuration for ad badges.
  AdBadgeConfiguration? get adBadgeConfiguration => _adBadgeConfiguration;
  set adBadgeConfiguration(AdBadgeConfiguration? adBadgeConfiguration) {
    _adBadgeConfiguration = adBadgeConfiguration;
    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setAdBadgeConfiguration);
    Map<String, dynamic> arg = {};
    if (adBadgeConfiguration != null) {
      arg = AdBadgeConfigurationUtil.toJson(adBadgeConfiguration);
    }
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, arg)
        .then(
      (_) {
        FWEventBus.getInstance().fire(
          FWEvent(
            eventName: FWEventName.adBadgeConfigurationUpdated,
          ),
        );
      },
    );
  }

  /// LiveStream instance.
  LiveStream get liveStream => LiveStream.getInstance();

  /// The callback of clicking custom CTA.
  CustomCTAClickCallback? get onCustomCTAClick => _onCustomCTAClick;
  set onCustomCTAClick(CustomCTAClickCallback? newValue) {
    _onCustomCTAClick = newValue;

    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setCustomCTAClickEnabled);
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, newValue != null);
  }

  /// The callback of video playback.
  VideoPlaybackCallback? get onVideoPlayback => _onVideoPlayback;

  set onVideoPlayback(VideoPlaybackCallback? newValue) {
    _onVideoPlayback = newValue;

    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setVideoPlaybackEventEnabled);
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeListMethod(nativeMethodName, newValue != null);
  }

  /// The share base URL of videos.
  String? get shareBaseURL => _shareBaseURL;

  set shareBaseURL(String? shareBaseURL) {
    _shareBaseURL = shareBaseURL;
    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setShareBaseURL);
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeListMethod(nativeMethodName, _shareBaseURL)
        .then(
      (_) {
        FWEventBus.getInstance().fire(
          FWEvent(
            eventName: FWEventName.shareBaseURLUpdated,
          ),
        );
      },
    );
  }

  /// VideoShopping instance.
  VideoShopping get shopping => VideoShopping.getInstance();

  /// Initializes Firework SDK.
  ///
  /// [userId] is used to uniquely identify device or user.
  /// [adConfig] is the configuration of Advertisement.
  void init({
    String? userId,
    AdConfig? adConfig,
  }) {
    final nativeMethodName =
        FWMethodNameUtil.convertToNativeMethod(FWNativeMethodName.init);
    Map<String, dynamic> arg = {};
    if (userId != null) {
      arg["userId"] = userId;
    }

    if (adConfig != null) {
      arg["adConfig"] = AdConfigUtil.toJson(adConfig);
    }

    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, arg);

    final shoppingInitNativeMethodName =
        FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.init,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      shoppingInitNativeMethodName,
    );

    final liveStreamInitNativeMethodName =
        FWLiveStreamMethodNameUtil.convertToNativeMethod(
            FWLiveStreamNativeMethodName.init);
    FWMethodChannelUtil.getLiveStreamMethodChannel()
        .invokeMethod(liveStreamInitNativeMethodName);
  }

  /// Opens video [url] with the [config].
  void openVideoPlayer({
    required String url,
    VideoPlayerConfiguration? config,
  }) {
    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.openVideoPlayer);
    Map<String, dynamic> arg = {
      "url": url,
    };

    if (config != null) {
      arg["config"] = VideoPlayerConfigurationUtil.toJson(config);
    }

    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, arg);
  }

  static FireworkSDK _getInstance() {
    _instance ??= FireworkSDK._();
    return _instance!;
  }
}

==> 1.5.1.tar.gz: lib/src/firework_sdk.dart <==
import 'package:flutter/foundation.dart';
import 'constants/fw_error_name.dart';
import 'constants/fw_event_name.dart';
import 'fw_event_bus.dart';
import 'fw_navigator.dart';
import 'live_stream.dart';
import 'models/ad_badge_configuration.dart';
import 'models/fw_error.dart';
import 'models/fw_events.dart';
import 'models/fw_method_name.dart';
import 'models/track_purchase_parameters.dart';
import 'models/video_player_configuration.dart';
import 'utils/fw_method_channel_util.dart';
import 'utils/model_utils/ad_badge_configuration_util.dart';
import 'utils/model_utils/fw_events_util.dart';
import 'utils/model_utils/fw_method_name_util.dart';
import 'utils/model_utils/track_purchase_parameters_util.dart';
import 'utils/model_utils/video_player_configuration_util.dart';
import 'video_shopping.dart';

typedef CustomCTAClickCallback = void Function(CustomCTAClickEvent? event);
typedef SDKInitCallback = void Function(SDKInitEvent event);
typedef VideoFeedClickCallback = void Function(VideoFeedClickEvent? event);
typedef VideoPlaybackCallback = void Function(VideoPlaybackEvent? event);

/// The entry class of Firework Flutter SDK, which supports the sdk initialization, global configuration, etc.
class FireworkSDK {
  static FireworkSDK? _instance;

  /// The callback of SDK initialization.
  SDKInitCallback? onSDKInit;

  CustomCTAClickCallback? _onCustomCTAClick;
  VideoPlaybackCallback? _onVideoPlayback;

  /// The callback of clicking video feed.
  VideoFeedClickCallback? onVideoFeedClick;

  String? _shareBaseURL;
  AdBadgeConfiguration? _adBadgeConfiguration;

  /// Get global single instance of FireworkSDK class.
  factory FireworkSDK.getInstance() => _getInstance();

  FireworkSDK._() {
    FWMethodChannelUtil.getFirewokSDKChannel()
        .setMethodCallHandler((call) async {
      final fwMethod = FWMethodNameUtil.createMethodName(call.method);
      if (fwMethod == null) {
        return null;
      }

      switch (fwMethod) {
        case FWMethodName.sdkInit:
          final sdkInitEvent = SDKInitEventUtil.fromJson(call.arguments);
          if (sdkInitEvent != null) {
            onSDKInit?.call(
              sdkInitEvent,
            );
          } else {
            onSDKInit?.call(
              SDKInitEvent(
                error: FWError(
                  name: FWErrorName.parseJsonError,
                  reason: "Fail to parse SDK init event",
                ),
              ),
            );
          }
          break;
        case FWMethodName.customCTAClick:
          onCustomCTAClick?.call(
            CustomCTAClickEventUtil.fromJson(
              call.arguments,
            ),
          );
          break;
        case FWMethodName.videoPlayback:
          onVideoPlayback?.call(
            VideoPlaybackEventUtil.fromJson(
              call.arguments,
            ),
          );
          break;
        case FWMethodName.videoFeedClick:
          onVideoFeedClick?.call(
            VideoFeedClickEventUtil.fromJson(
              call.arguments,
            ),
          );
          break;
      }

      return null;
    });
  }

  /// The configuration for ad badges.
  AdBadgeConfiguration? get adBadgeConfiguration => _adBadgeConfiguration;
  set adBadgeConfiguration(AdBadgeConfiguration? adBadgeConfiguration) {
    _adBadgeConfiguration = adBadgeConfiguration;
    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setAdBadgeConfiguration);
    Map<String, dynamic> arg = {};
    if (adBadgeConfiguration != null) {
      arg = AdBadgeConfigurationUtil.toJson(adBadgeConfiguration);
    }
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, arg)
        .then(
      (_) {
        FWEventBus.getInstance().fire(
          FWEvent(
            eventName: FWEventName.adBadgeConfigurationUpdated,
          ),
        );
      },
    );
  }

  /// LiveStream instance.
  LiveStream get liveStream => LiveStream.getInstance();

  /// The callback of clicking custom CTA.
  CustomCTAClickCallback? get onCustomCTAClick => _onCustomCTAClick;
  set onCustomCTAClick(CustomCTAClickCallback? newValue) {
    _onCustomCTAClick = newValue;

    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setCustomCTAClickEnabled);
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, newValue != null);
  }

  /// The callback of video playback.
  VideoPlaybackCallback? get onVideoPlayback => _onVideoPlayback;

  set onVideoPlayback(VideoPlaybackCallback? newValue) {
    _onVideoPlayback = newValue;

    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setVideoPlaybackEventEnabled);
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeListMethod(nativeMethodName, newValue != null);
  }

  /// The share base URL of videos.
  String? get shareBaseURL => _shareBaseURL;

  set shareBaseURL(String? shareBaseURL) {
    _shareBaseURL = shareBaseURL;
    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.setShareBaseURL);
    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeListMethod(nativeMethodName, _shareBaseURL)
        .then(
      (_) {
        FWEventBus.getInstance().fire(
          FWEvent(
            eventName: FWEventName.shareBaseURLUpdated,
          ),
        );
      },
    );
  }

  /// VideoShopping instance.
  VideoShopping get shopping => VideoShopping.getInstance();

  /// FWNavigator instance.
  FWNavigator get navigator => FWNavigator.getInstance();

  /// Initializes Firework SDK.
  ///
  /// [userId] is used to uniquely identify device or user.
  void init({
    String? userId,
  }) {
    final nativeMethodName =
        FWMethodNameUtil.convertToNativeMethod(FWNativeMethodName.init);
    Map<String, dynamic> arg = {};
    if (userId != null) {
      arg["userId"] = userId;
    }

    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, arg);

    final shoppingInitNativeMethodName =
        FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.init,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      shoppingInitNativeMethodName,
    );

    final liveStreamInitNativeMethodName =
        FWLiveStreamMethodNameUtil.convertToNativeMethod(
            FWLiveStreamNativeMethodName.init);
    FWMethodChannelUtil.getLiveStreamMethodChannel()
        .invokeMethod(liveStreamInitNativeMethodName);
  }

  /// Opens video [url] with the [config].
  void openVideoPlayer({
    required String url,
    VideoPlayerConfiguration? config,
  }) {
    final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
        FWNativeMethodName.openVideoPlayer);
    Map<String, dynamic> arg = {
      "url": url,
    };

    if (config != null) {
      arg["config"] = VideoPlayerConfigurationUtil.toJson(config);
    }

    FWMethodChannelUtil.getFirewokSDKChannel()
        .invokeMethod(nativeMethodName, arg);
  }

  /// Records the user purchase.
  void trackPurchase(TrackPurchaseParameters parameters) {
    if (defaultTargetPlatform == TargetPlatform.iOS) {
      final nativeMethodName = FWMethodNameUtil.convertToNativeMethod(
          FWNativeMethodName.trackPurchase);
      FWMethodChannelUtil.getFirewokSDKChannel().invokeMethod(
          nativeMethodName, TrackPurchaseParametersUtil.toJson(parameters));
    }
  }

  static FireworkSDK _getInstance() {
    _instance ??= FireworkSDK._();
    return _instance!;
  }
}
